@@ -54,7 +54,7 @@ test_with_dir("empty grouping levels", {
   out <- drake_plan(x = target(y, transform = map(y = c(z, NULL))))
   exp <- weak_tibble(
     target = c("x_z", "x_NULL"),
-    command = c("z", "")
+    command = c("z", "expression(NULL)")
   )
   equivalent_plans(out, exp)
 })
